@@ -1,9 +1,18 @@
 # -*- coding: utf-8 -*-
 
 """
-Provide hash functions.
+Provide file hash functions.
 """
 
+try:  # pragma: no cover
+    from typing import TYPE_CHECKING
+
+    if TYPE_CHECKING:
+        from .pathlib2 import Path
+
+except ImportError:  # pragma: no cover
+    pass
+
 from .hashes import md5file, sha256file, sha512file
 
 
@@ -11,11 +20,17 @@ class HashesMethods(object):
     """
     Provide hash functions.
     """
+
     # --- file check sum ---
 
     def get_partial_md5(self, nbytes):
         """
         Return md5 check sum of first n bytes of this file.
+
+        :type self: Path
+        :type nbytes: int
+
+        :rtype: str
         """
         return md5file(abspath=self.abspath, nbytes=nbytes)
 
@@ -23,12 +38,21 @@ class HashesMethods(object):
     def md5(self):
         """
         Return md5 check sum of this file.
+
+        :type self: Path
+
+        :rtype: str
         """
         return md5file(self.abspath)
 
     def get_partial_sha256(self, nbytes):
         """
         Return sha256 check sum of first n bytes of this file.
+
+        :type self: Path
+        :type nbytes: int
+
+        :rtype: str
         """
         return sha256file(abspath=self.abspath, nbytes=nbytes)
 
@@ -36,12 +60,21 @@ class HashesMethods(object):
     def sha256(self):
         """
         Return sha256 check sum of this file.
+
+        :type self: Path
+
+        :rtype: str
         """
         return sha256file(self.abspath)
 
     def get_partial_sha512(self, nbytes):
         """
         Return sha512 check sum of first n bytes of this file.
+
+        :type self: Path
+        :type nbytes: int
+
+        :rtype: str
         """
         return sha512file(abspath=self.abspath, nbytes=nbytes)
 
@@ -49,5 +82,9 @@ class HashesMethods(object):
     def sha512(self):
         """
         Return md5 check sum of this file.
+
+        :type self: Path
+
+        :rtype: str
         """
         return sha512file(self.abspath)
